# Autogenerated constants for Flex service
from enum import IntEnum
from jacdac.constants import *
from jacdac.system.constants import *
JD_SERVICE_CLASS_FLEX = const(0x1f47c6c6)


class FlexVariant(IntEnum):
    LINEAR22INCH = const(0x1)
    LINEAR45INCH = const(0x2)


JD_FLEX_REG_BENDING = const(JD_REG_READING)
JD_FLEX_REG_VARIANT = const(JD_REG_VARIANT)
JD_FLEX_PACK_FORMATS = {
    JD_FLEX_REG_BENDING: "u0.16",
    JD_FLEX_REG_VARIANT: "u8"
}
